@@ -16,6 +16,7 @@ const metadataName = 'metadata.name';
 const metadataNamespace = 'metadata.namespace';
 const preHookType = 'pre-hook';
 const postHookType = 'post-hook';
+const specTemplate = 'spec.template';
 
 export const isPrePostHookDeployable = (subscription, name, namespace) => {
   const preHooks = _.get(subscription, 'status.ansiblejobs.prehookjobshistory', []);
@@ -75,6 +76,17 @@ function addSubscriptionRules(parentId, subscription, links, nodes) {
   });
 }
 
+export const getLocalClusterElement = (createdClusterElements) => {
+  let localClusterElement;
+  createdClusterElements.forEach((element) => {
+    if (element.indexOf(localClusterName) > -1) {
+      localClusterElement = element;
+    }
+  });
+
+  return localClusterElement;
+};
+
 export const addClusters = (
   parentId, createdClusterElements, subscription,
   clusterNames, clusters, links, nodes,
@@ -82,8 +94,10 @@ export const addClusters = (
   // create element if not already created'
   const sortedClusterNames = _.sortBy(clusterNames);
   const cns = sortedClusterNames.join(', ');
-  const clusterId = `member--clusters--${cns}`;
-  if (!createdClusterElements.has(clusterId)) {
+  let clusterId = `member--clusters--${cns}`;
+  const localClusterElement = clusterNames.length === 1 && clusterNames[0] === localClusterName
+    ? getLocalClusterElement(createdClusterElements) : undefined;
+  if (!createdClusterElements.has(clusterId) && !localClusterElement) {
     const filteredClusters = clusters.filter((cluster) => {
       const cname = _.get(cluster, metadataName);
       return cname && clusterNames.includes(cname);
@@ -102,6 +116,9 @@ export const addClusters = (
     });
     createdClusterElements.add(clusterId);
   }
+  if (localClusterElement) {
+    clusterId = localClusterElement;
+  }
   links.push({
     from: { uid: parentId },
     to: { uid: clusterId },
@@ -124,33 +141,13 @@ const getClusterName = (nodeId) => {
   return localClusterName;
 };
 
-export const createReplicaChild = (parentObject, template, links, nodes) => {
-  if (!_.get(parentObject, 'specs.raw.spec.replicas')) {
-    return null; // no replica
-  }
+const createChildNode = (parentObject, type, rawData, links, nodes) => {
   const parentType = _.get(parentObject, 'type', '');
-  if (parentType !== 'deploymentconfig' && parentType !== 'deployment') {
-    // create only for deploymentconfig and deployment types
-    return null;
-  }
-
-  const type = parentType === 'deploymentconfig' ? 'replicationcontroller' : 'replicaset';
   const { name, namespace } = parentObject;
 
   const parentId = parentObject.id;
   const memberId = `member--member--deployable--member--clusters--${getClusterName(parentId)}--${type}--${name}`;
 
-  const rawData = {
-    kind: type,
-    metadata: {
-      name,
-      namespace,
-    },
-    spec: {
-      desired: _.get(template, 'spec.replicas', 0),
-      template: { ..._.get(template, 'spec.template', {}) },
-    },
-  };
   const deployableObj = {
     name,
     namespace,
@@ -178,6 +175,73 @@ export const createReplicaChild = (parentObject, template, links, nodes) => {
   return deployableObj;
 };
 
+export const createControllerRevisionChild = (parentObject, template, links, nodes) => {
+  const parentType = _.get(parentObject, 'type', '');
+  if (parentType !== 'daemonset' && parentType !== 'statefulset') {
+    // create only for daemonset or statefulset types
+    return null;
+  }
+
+  const { name, namespace } = parentObject;
+  const rawData = {
+    kind: 'controllerrevision',
+    metadata: {
+      name,
+      namespace,
+    },
+    spec: {
+      template: { ..._.get(template, specTemplate, {}) },
+    },
+  };
+  return createChildNode(parentObject, 'controllerrevision', rawData, links, nodes);
+};
+
+export const createReplicaChild = (parentObject, template, links, nodes) => {
+  if (!_.get(parentObject, 'specs.raw.spec.replicas')) {
+    return null; // no replica
+  }
+  const parentType = _.get(parentObject, 'type', '');
+  if (parentType !== 'deploymentconfig' && parentType !== 'deployment') {
+    // create only for deploymentconfig and deployment types
+    return null;
+  }
+  const { name, namespace } = parentObject;
+  const type = parentType === 'deploymentconfig' ? 'replicationcontroller' : 'replicaset';
+  const rawData = {
+    kind: type,
+    metadata: {
+      name,
+      namespace,
+    },
+    spec: {
+      desired: _.get(template, 'spec.replicas', 0),
+      template: { ..._.get(template, specTemplate, {}) },
+    },
+  };
+  return createChildNode(parentObject, type, rawData, links, nodes);
+};
+
+export const createIngressRouteChild = (parentObject, template, links, nodes) => {
+  const parentType = _.get(parentObject, 'type', '');
+  if (parentType !== 'ingress') {
+    return null; // not an ingress object
+  }
+  const { name, namespace } = parentObject;
+  const type = 'route';
+
+  const rawData = {
+    kind: 'Route',
+    metadata: {
+      name,
+      namespace,
+    },
+    spec: {
+      rules: _.get(template, 'spec.rules', []),
+    },
+  };
+  return createChildNode(parentObject, type, rawData, links, nodes);
+};
+
 export const addSubscriptionDeployable = (
   parentId, deployable, links, nodes,
   subscriptionStatusMap, names, appNamespace, subscription,
@@ -217,7 +281,7 @@ export const addSubscriptionDeployable = (
       parentType: parentNode.type,
     } : undefined;
 
-  const template = _.get(deployable, 'spec.template', { metadata: {} });
+  const template = _.get(deployable, specTemplate, { metadata: {} });
   let { kind = 'container' } = template;
   const { metadata: { name: k8Name } } = template;
   kind = kind.toLowerCase();
@@ -257,8 +321,12 @@ export const addSubscriptionDeployable = (
       type: linkType,
     });
   }
-  // create subobject replica subobject, if this object defines a replicas
+  // create replica subobject, if this object defines a replicas
   createReplicaChild(topoObject, template, links, nodes);
+  // create controllerrevision subobject, if this object is a daemonset
+  createControllerRevisionChild(topoObject, template, links, nodes);
+  // create route subobject, if this object is an ingress
+  createIngressRouteChild(topoObject, template, links, nodes);
 
   return topoObject;
 };
@@ -402,23 +470,26 @@ export const createGenericPackageObject = (
 
 export const removeReleaseGeneratedSuffix = (name) => name.replace(/-[0-9a-zA-Z]{4,5}$/, '');
 
-// remove the release name from the deployable name
-export const removeHelmReleaseName = (name, releaseName) => {
-  const trimmedReleaseName = _.trimEnd(releaseName, '-');
-  let result = _.replace(name, `${trimmedReleaseName}-`, '');
-  result = _.replace(result, `${trimmedReleaseName}`, '');
-
-  // resource name only contains release name, return without the generated suffix
-  if (result.length === 0) {
+// use the package name if name is set using alias
+export const removeHelmReleaseName = (name, releaseName, packageName, aliasName) => {
+  if (!aliasName) {
+    // if no alias name set, the resource name ends with a chart hash, remove that
     return removeReleaseGeneratedSuffix(name);
   }
-  return result;
+
+  if (packageName && aliasName && `${name}-` === releaseName && name === aliasName) {
+    return packageName; // if name matches alias use package name instead
+  }
+
+  return name;
 };
 
 export const getSubscriptionPackageInfo = (topoAnnotation, subscriptionName, appNamespace, channelInfo, subscription) => {
   const deployablesList = [];
 
   const deployables = _.split(topoAnnotation, ',');
+  const packageName = _.get(_.get(subscription, 'spec.packageOverrides', [{}])[0], 'packageName');
+  const aliasName = _.get(_.get(subscription, 'spec.packageOverrides', [{}])[0], 'packageAlias');
 
   deployables.forEach((deployableInfo) => {
     const deployableData = _.split(deployableInfo, '/');
@@ -434,7 +505,7 @@ export const getSubscriptionPackageInfo = (topoAnnotation, subscriptionName, app
       // process only helm charts and hooks
       if (deployableData[0] === 'helmchart' || isHook) {
         if (!isHook) {
-          dName = removeHelmReleaseName(deployableData[4], deployableData[1]);
+          dName = removeHelmReleaseName(deployableData[4], deployableData[1], packageName, aliasName);
           namespace = deployableData[3].length === 0 ? appNamespace : deployableData[3];
           deployableName = `${subscriptionName}-${dName}-${dName}-${deployableTypeLower}`;
         }
@@ -589,6 +660,7 @@ async function getApplicationElements(application, clusterModel) {
   let name;
   let namespace;
   ({ name, namespace } = application);
+  const allAppClusters = application.allClusters ? application.allClusters : [];
   const appId = `application--${name}`;
   nodes.push({
     name,
@@ -600,6 +672,12 @@ async function getApplicationElements(application, clusterModel) {
       isDesign: true,
       raw: application.app,
       activeChannel: application.activeChannel,
+      allSubscriptions: application.allSubscriptions ? application.allSubscriptions : [],
+      allChannels: application.allChannels ? application.allChannels : [],
+      allClusters: {
+        isLocal: allAppClusters.indexOf(localClusterName) !== -1,
+        remoteCount: allAppClusters.indexOf('local-cluster') !== -1 ? allAppClusters.length - 1 : allAppClusters.length,
+      },
       channels: application.channels,
     },
   });
